; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted


;-| Super Motions |--------------------------------------------------------

[Command]
name = QCBHCFab
command = ~D, DB, B, DB, D, DF, F, a+b
time = 50

[Command]
name = QCBHCFa
command = ~D, DB, B, DB, D, DF, F, a
time = 50

[Command]
name = QCBHCFb
command = ~D, DB, B, DB, D, DF, F, b
time = 50

[Command]
name = DM_D3
command = ~D, DB, B, DB, D, DF, F, x+y
time = 45

[Command]
name = DM_D
command = ~D, DB, B, DB, D, DF, F, x
time = 45

[Command]
name = DM_D2
command = ~D, DB, B, DB, D, DF, F, y
time = 45

[Command]
name = FinishA3
command = ~F, B, DB, D, DF, F, a+b
time = 50

[Command]
name = FinishA1
command = ~F, B, DB, D, DF, F, a
time = 50

[Command]
name = FinishA2
command = ~F, B, DB, D, DF, F, b
time = 50

[Command]
name = 2QCB_xy
command = ~D, DB, B, D, DB, B, x+y
time = 45

[Command]
name = 2QCB_y
command = ~D, DB, B, D, DB, B, y
time = 45

[Command]
name = 2QCB_x
command = ~D, DB, B, D, DB, B, x
time = 45

[Command]
name = QCFxy*2
command = ~D, DF, F, D, DF, F, x+y
time = 30

[Command]
name = QCFx*2
command = ~D, DF, F, D, DF, F, x
time = 30

[Command]
name = QCFy*2
command = ~D, DF, F, D, DF, F, y
time = 30

[Command]
name = QCFz*2
command = ~D, DF, F, D, DF, F, z
time = 30

[Command]
name = QCFHCBx
command = ~D, DF, F, DF, D, DB,B,x
time = 50

[Command]
name = QCFHCBy
command = ~D, DF, F, DF, D, DB,B,y
time = 50

[Command]
name = QCFHCBxy
command = ~D, DF, F, DF, D, DB,B,y+x
time = 50

[Command]
name = QCF*2a
command = ~D, DF, F, D, DF, F, a
time = 30

[Command]
name = QCF*2b
command = ~D, DF, F, D, DF, F, b
time = 30

[Command]
name = QCF*2c
command = ~D, DF, F, D, DF, F, c
time = 30


[Command]
name = FHCFx
command = ~F, B, DB, D, DF, F, x
time = 50

[Command]
name = FHCFy
command = ~F, B, DB, D, DF, F, y
time = 50

;-| Special Motions |------------------------------------------------------

[Command]
name = DP_x
command = ~F, D, DF, x 

[Command]
name = DP_y
command = ~F, D, DF, y

[Command]
name = DP_z
command = ~F, D, DF, z

[Command]
name = DP_a
command = ~F, D, DF, a

[Command]
name = DP_b
command = ~F, D, DF, b

[Command]
name = DP_c
command = ~F, D, DF, c


[Command]
name = QCF_a
command = ~D, DF, F, a

[Command]
name = QCF_b
command = ~D, DF, F, b

[Command]
name = QCF_c
command = ~D, DF, F, c

[Command]
name = QCF_x
command = ~D, DF, F, x

[Command]
name = QCF_y
command = ~D, DF, F, y

[Command]
name = QCF_z
command = ~D, DF, F, z

[Command]
name = QCB_a
command = ~D, DB, B, a

[Command]
name = QCB_b
command = ~D, DB, B, b

[Command]
name = QCB_c
command = ~D, DB, B, c

[Command]
name = QCB_x
command = ~D, DB, B, x

[Command]
name = QCB_y
command = ~D, DB, B, y

[Command]
name = QCB_z
command = ~D, DB, B, z

[Command]
name = HCF_a
command = ~B, DB, D, DF, F, a

[Command]
name = HCF_b
command = ~B, DB, D, DF, F, b


[Command]
name = throw_d
command = /F,b
time = 1
[Command]
name = throw_d
command = /B,b
time = 1

[Command]
name = throw_y
command = /F,y
time = 1
[Command]
name = throw_y
command = /B,y
time = 1

;-| Double Tap |-----------------------------------------------------------
[Command]
name = FF       ;Required (do not remove)
command = F, F
time = 10

[Command]
name = BB       ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = recovery ;Required (do not remove)
command = a+b
time = 1

[Command]
name = cd
command = a+b
time = 1

[Command]
name = xy
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = fwd_a
command = /F,a
time = 1

[Command]
name = fwd_b
command = /F,b
time = 1

[Command]
name = fwd_c
command = /F,c
time = 1

[Command]
name = downfwd_a
command = /DF,a
time = 1

[Command]
name = downfwd_b
command = /DF,b
time = 1

[Command]
name = back_a
command = /B,a
time = 1

[Command]
name = back_b
command = /B,b
time = 1

[Command]
name = back_c
command = /B,c
time = 1

[Command]
name = down_a
command = /$D,a
time = 1

[Command]
name = down_b
command = /$D,b
time = 1

[Command]
name = down_c
command = /$D,c
time = 1

[Command]
name = fwd_ab
command = /F, a+b
time = 1

[Command]
name = back_ab
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = a
command = a
time = 1

[Command]
name = b
command = b
time = 1

[Command]
name = c
command = c
time = 1

[Command]
name = x
command = x
time = 1

[Command]
name = y
command = y
time = 1

[Command]
name = z
command = z
time = 1

;-| Hold Button |-----------------------------------------------------------

[Command]
name = hold_a
command = /a
time = 1

[Command]
name = hold_b
command = /b
time = 1

[Command]
name = hold_c
command = /c
time = 1

[Command]
name = hold_x
command = /x
time = 1

[Command]
name = hold_y
command = /y
time = 1
[Command]
name = hold_z
command = /z
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = holdfwd  ;Required (do not remove)
command = /$F
time = 1

[Command]
name = holdback ;Required (do not remove)
command = /$B
time = 1

[Command]
name = holdup   ;Required (do not remove)
command = /$U
time = 1

[Command]
name = holddown ;Required (do not remove)
command = /$D
time = 1

[Command]
name = holdDF ;Required (do not remove)
command = /$DF
time = 1

[Command]
name = holdDB ;Required (do not remove)
command = /$DB
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------

;---------------------------------------------------------------------------

;Death move C a Mika's Galactica Phamtom(QCF*2 +kick)
[State -1]
type = ChangeState
value = 3200
triggerall = command = QCF*2a
;triggerall = stateno != 3301
;triggerall = stateno != 3306
triggerall = statetype != A
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 400
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 213
trigger7 = movecontact = 1
trigger8 = stateno = 211
trigger8 = movecontact = 1
trigger9 = stateno = 201
trigger9 = movecontact = 1
trigger10 = stateno = 203
trigger10= movecontact = 1
trigger11 = stateno = 1000
trigger11= movecontact = 1
trigger12 = stateno = 401
trigger12 = movecontact = 1
trigger13 = stateno = 411
trigger13 = movecontact = 1
trigger14 = stateno = 214
trigger14 = movecontact = 1
trigger15 = stateno = 204
trigger15 = movecontact = 1
trigger16 = stateno = 240
trigger16 = movecontact = 1

;Death move C b Mika's Galactica Phamtom(QCF*2 +kick)
[State -1]
type = ChangeState
value = 3204
triggerall = command = QCF*2b
;triggerall = stateno != 3301
;triggerall = stateno != 3306
triggerall = statetype != A
triggerall = power >= 2000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 400
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 213
trigger7 = movecontact = 1
trigger8 = stateno = 211
trigger8 = movecontact = 1
trigger9 = stateno = 201
trigger9 = movecontact = 1
trigger10 = stateno = 203
trigger10= movecontact = 1
trigger11 = stateno = 1000
trigger11= movecontact = 1
trigger12 = stateno = 401
trigger12 = movecontact = 1
trigger13 = stateno = 411
trigger13 = movecontact = 1
trigger14 = stateno = 214
trigger14 = movecontact = 1
trigger15 = stateno = 204
trigger15 = movecontact = 1
trigger16 = stateno = 240
trigger16 = movecontact = 1

;Death move C c Mika's Galactica Phamtom(QCF*2 +kick)
[State -1]
type = ChangeState
value = 3204
triggerall = command = QCF*2c
;triggerall = stateno != 3301
;triggerall = stateno != 3306
triggerall = statetype != A
triggerall = power >= 2000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 400
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 213
trigger7 = movecontact = 1
trigger8 = stateno = 211
trigger8 = movecontact = 1
trigger9 = stateno = 201
trigger9 = movecontact = 1
trigger10 = stateno = 203
trigger10= movecontact = 1
trigger11 = stateno = 1000
trigger11= movecontact = 1
trigger12 = stateno = 401
trigger12 = movecontact = 1
trigger13 = stateno = 411
trigger13 = movecontact = 1
trigger14 = stateno = 214
trigger14 = movecontact = 1
trigger15 = stateno = 204
trigger15 = movecontact = 1
trigger16 = stateno = 240
trigger16 = movecontact = 1

;--------------
;Death move B x (QCF*2 +Punch)
[State -1]
type = ChangeState
value = 3100
triggerall = command = QCFx*2
;triggerall = stateno != 3301
;triggerall = stateno != 3306
triggerall = statetype != A
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 400
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 213
trigger7 = movecontact = 1
trigger8 = stateno = 211
trigger8 = movecontact = 1
trigger9 = stateno = 201
trigger9 = movecontact = 1
trigger10 = stateno = 203
trigger10= movecontact = 1
trigger11 = stateno = 1000
trigger11= movecontact = 1
trigger12 = stateno = 401
trigger12 = movecontact = 1
trigger13 = stateno = 411
trigger13 = movecontact = 1
trigger14 = stateno = 214
trigger14 = movecontact = 1
trigger15 = stateno = 204
trigger15 = movecontact = 1
trigger16 = stateno = 240
trigger16 = movecontact = 1

;Death move B y (QCF*2 +Punch)
[State -1]
type = ChangeState
value = 3104
triggerall = command = QCFy*2
;triggerall = stateno != 3301
;triggerall = stateno != 3306
triggerall = statetype != A
triggerall = power >= 2000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 400
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 213
trigger7 = movecontact = 1
trigger8 = stateno = 211
trigger8 = movecontact = 1
trigger9 = stateno = 201
trigger9 = movecontact = 1
trigger10 = stateno = 203
trigger10= movecontact = 1
trigger11 = stateno = 1000
trigger11= movecontact = 1
trigger12 = stateno = 401
trigger12 = movecontact = 1
trigger13 = stateno = 411
trigger13 = movecontact = 1
trigger14 = stateno = 214
trigger14 = movecontact = 1
trigger15 = stateno = 204
trigger15 = movecontact = 1
trigger16 = stateno = 240
trigger16 = movecontact = 1

;Death move B z (QCF*2 +Punch)
[State -1]
type = ChangeState
value = 3100
triggerall = command = QCFz*2
;triggerall = stateno != 3301
;triggerall = stateno != 3306
triggerall = statetype != A
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 400
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 213
trigger7 = movecontact = 1
trigger8 = stateno = 211
trigger8 = movecontact = 1
trigger9 = stateno = 201
trigger9 = movecontact = 1
trigger10 = stateno = 203
trigger10= movecontact = 1
trigger11 = stateno = 1000
trigger11= movecontact = 1
trigger12 = stateno = 401
trigger12 = movecontact = 1
trigger13 = stateno = 411
trigger13 = movecontact = 1
trigger14 = stateno = 214
trigger14 = movecontact = 1
trigger15 = stateno = 204
trigger15 = movecontact = 1
trigger16 = stateno = 240
trigger16 = movecontact = 1

;-----------------------------------------------

;Death move A x (QCB*2 +Punch)
[State -1]
type = ChangeState
value = 3000
triggerall = command = 2QCB_x
;triggerall = stateno != 3301
;triggerall = stateno != 3306
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 400
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 213
trigger7 = movecontact = 1
trigger8 = stateno = 211
trigger8 = movecontact = 1
trigger9 = stateno = 201
trigger9 = movecontact = 1
trigger10 = stateno = 203
trigger10= movecontact = 1
trigger11 = stateno = 1000
trigger11= movecontact = 1
trigger12 = stateno = 401
trigger12 = movecontact = 1
trigger13 = stateno = 411
trigger13 = movecontact = 1
trigger14 = stateno = 214
trigger14 = movecontact = 1
trigger15 = stateno = 204
trigger15 = movecontact = 1
trigger16 = stateno = 240
trigger16 = movecontact = 1

;Death move A y (QCB*2 +Punch)
[State -1]
type = ChangeState
value = 3003
triggerall = command = 2QCB_y
;triggerall = stateno != 3301
;triggerall = stateno != 3306
triggerall = power >= 2000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 400
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 213
trigger7 = movecontact = 1
trigger8 = stateno = 211
trigger8 = movecontact = 1
trigger9 = stateno = 201
trigger9 = movecontact = 1
trigger10 = stateno = 203
trigger10= movecontact = 1
trigger11 = stateno = 1000
trigger11= movecontact = 1
trigger12 = stateno = 401
trigger12 = movecontact = 1
trigger13 = stateno = 411
trigger13 = movecontact = 1
trigger14 = stateno = 214
trigger14 = movecontact = 1
trigger15 = stateno = 204
trigger15 = movecontact = 1
trigger16 = stateno = 240
trigger16 = movecontact = 1

;---------------------------------------------------------------------------
;===========================================================================
;---------------------------------------------------------------------------
;SpecialA c
[State -1]
type = ChangeState
value = 1002
triggerall = command = QCB_c
triggerall = statetype != A
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 213
trigger6 = movecontact = 1
trigger7 = stateno = 211
trigger7 = movecontact = 1
trigger8 = stateno = 201
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 411
trigger11 = movecontact = 1
trigger12 = stateno = 214
trigger12 = movecontact = 1
trigger13 = stateno = 204
trigger13 = movecontact = 1
trigger14 = stateno = 240
trigger14 = movecontact = 1

;SpecialA a
[State -1]
type = ChangeState
value = 1000
triggerall = command = QCB_a
triggerall = statetype != A
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 213
trigger6 = movecontact = 1
trigger7 = stateno = 211
trigger7 = movecontact = 1
trigger8 = stateno = 201
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 411
trigger11 = movecontact = 1
trigger12 = stateno = 214
trigger12 = movecontact = 1
trigger13 = stateno = 204
trigger13 = movecontact = 1
trigger14 = stateno = 240
trigger14 = movecontact = 1
;------------------------------

;SpecialA b
[State -1]
type = ChangeState
value = 1002
triggerall = command = QCB_b
triggerall = statetype != A
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 213
trigger6 = movecontact = 1
trigger7 = stateno = 211
trigger7 = movecontact = 1
trigger8 = stateno = 201
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 411
trigger11 = movecontact = 1
trigger12 = stateno = 214
trigger12 = movecontact = 1
trigger13 = stateno = 204
trigger13 = movecontact = 1
trigger14 = stateno = 240
trigger14 = movecontact = 1

;---------------------------------------------------------------------------
;SpecialB x
[State -1]
type = ChangeState
value = 1010
triggerall = command = QCB_x
triggerall = statetype != A
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 213
trigger6 = movecontact = 1
trigger7 = stateno = 211
trigger7 = movecontact = 1
trigger8 = stateno = 201
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 411
trigger11 = movecontact = 1
trigger12 = stateno = 214
trigger12 = movecontact = 1
trigger13 = stateno = 204
trigger13 = movecontact = 1
trigger14 = stateno = 240
trigger14 = movecontact = 1
;---------------------------------------------------------------------------
;SpecialB y
[State -1]
type = ChangeState
value = 1013
triggerall = command = QCB_y
triggerall = statetype != A
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 213
trigger6 = movecontact = 1
trigger7 = stateno = 211
trigger7 = movecontact = 1
trigger8 = stateno = 201
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 411
trigger11 = movecontact = 1
trigger12 = stateno = 214
trigger12 = movecontact = 1
trigger13 = stateno = 204
trigger13 = movecontact = 1
trigger14 = stateno = 240
trigger14 = movecontact = 1

;---------------------------------------------------------------------------
;SpecialC a
[State -1]
type = ChangeState
value = 1020
triggerall = command = DP_a
triggerall = statetype != A
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 213
trigger6 = movecontact = 1
trigger7 = stateno = 211
trigger7 = movecontact = 1
trigger8 = stateno = 201
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 411
trigger11 = movecontact = 1
trigger12 = stateno = 214
trigger12 = movecontact = 1
trigger13 = stateno = 204
trigger13 = movecontact = 1
trigger14 = stateno = 240
trigger14 = movecontact = 1

;SpecialC b
[State -1]
type = ChangeState
value = 1023
triggerall = command = DP_b
triggerall = statetype != A
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 213
trigger6 = movecontact = 1
trigger7 = stateno = 211
trigger7 = movecontact = 1
trigger8 = stateno = 201
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 411
trigger11 = movecontact = 1
trigger12 = stateno = 214
trigger12 = movecontact = 1
trigger13 = stateno = 204
trigger13 = movecontact = 1
trigger14 = stateno = 240
trigger14 = movecontact = 1

;SpecialC c
[State -1]
type = ChangeState
value = 1023
triggerall = command = DP_c
triggerall = statetype != A
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 213
trigger6 = movecontact = 1
trigger7 = stateno = 211
trigger7 = movecontact = 1
trigger8 = stateno = 201
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 411
trigger11 = movecontact = 1
trigger12 = stateno = 214
trigger12 = movecontact = 1
trigger13 = stateno = 204
trigger13 = movecontact = 1
trigger14 = stateno = 240
trigger14 = movecontact = 1

;------------------------------
;SpecialD x
[State -1]
type = ChangeState
value = 1030
triggerall = command = QCF_x
triggerall = statetype != A
triggerall = p2bodydist X < 70
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 213
trigger6 = movecontact = 1
trigger7 = stateno = 211
trigger7 = movecontact = 1
trigger8 = stateno = 201
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 411
trigger11 = movecontact = 1
trigger12 = stateno = 214
trigger12 = movecontact = 1
trigger13 = stateno = 204
trigger13 = movecontact = 1
trigger14 = stateno = 240
trigger14 = movecontact = 1


;SpecialD y
[State -1]
type = ChangeState
value = 1030
triggerall = command = QCF_y
triggerall = statetype != A
triggerall = p2bodydist X < 70
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 213
trigger6 = movecontact = 1
trigger7 = stateno = 211
trigger7 = movecontact = 1
trigger8 = stateno = 201
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 411
trigger11 = movecontact = 1
trigger12 = stateno = 214
trigger12 = movecontact = 1
trigger13 = stateno = 204
trigger13 = movecontact = 1
trigger14 = stateno = 240
trigger14 = movecontact = 1

;SpecialD z
[State -1]
type = ChangeState
value = 1030
triggerall = command = QCF_z
triggerall = statetype != A
triggerall = p2bodydist X < 70
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 213
trigger6 = movecontact = 1
trigger7 = stateno = 211
trigger7 = movecontact = 1
trigger8 = stateno = 201
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 411
trigger11 = movecontact = 1
trigger12 = stateno = 214
trigger12 = movecontact = 1
trigger13 = stateno = 204
trigger13 = movecontact = 1
trigger14 = stateno = 240
trigger14 = movecontact = 1

;---------------------------------------------------------------------------
;Dodge Ret
[State -1]
type = ChangeState
value = 951
triggerall = stateno = 950
;triggerall = animelem = 3, < 0
trigger1 = command = a
trigger2 = command = b
trigger3 = command = x
trigger4 = command = y
trigger5 = command = c
trigger6 = command = z

;---------------------------------------------------------------------------
;Charge ABC
[State -1]
type = null;ChangeState
value = 960
triggerall = power < 3000
trigger1 = command = hold_a
trigger1 = command = hold_b
trigger1 = command = hold_x
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Dodge AB
[State -1]
type = ChangeState
value = 950
triggerall = command = xy
triggerall = stateno != 950
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Dodge AB
[State -1]
type = ChangeState
value = 950
triggerall = command = z
triggerall = stateno != 950
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;===========================================================================
;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1 = command = FF
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = BB
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;---------------------------------------------------------------------------
;Throw_D
[State -1]
type = null;ChangeState
value = 910
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = stateno != 100    ;Not running
triggerall = p2bodydist X < 15
trigger1 = command = throw_d   ;Near, p2 stand
trigger1 = p2statetype = S
trigger1 = p2movetype != H  ;P2 must not be in hit state
trigger2 = command = throw_d   ;Near, p2 crouch
trigger2 = p2statetype = C
trigger2 = p2movetype != H
;---------------------------------------------------------------------------
;Throw_Y
[State -1]
type = null;ChangeState
value = 900
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = stateno != 100    ;Not running
triggerall = p2bodydist X < 10
trigger1 = command = throw_y   ;Near, p2 stand
trigger1 = p2statetype = S
trigger1 = p2movetype != H  ;P2 must not be in hit state
trigger2 = command = throw_y   ;Near, p2 crouch
trigger2 = p2statetype = C
trigger2 = p2movetype != H
;---------------------------------------------------------------------------

;Air_Throw1
[State -1]
type = null;ChangeState
value = 950
triggerall = statetype = A
triggerall = ctrl = 1
trigger1 = command = fwd_ab
trigger2 = command = back_ab
;---------------------------
;Air_Throw1 (second set of commands)
[State -1]
type = null;ChangeState
value = 950
triggerall = statetype = A
triggerall = ctrl = 1
triggerall = p2bodydist X < 9
triggerall = p2bodydist Y > -22
triggerall = p2bodydist Y < 22
triggerall = p2statetype = A
triggerall = p2movetype != H
trigger1 = command = fwd_b
trigger2 = command = back_b


;===========================================================================
;---------------------------------------------------------------------------

;---------------------------------------------------------------------------

;---------------------------------------------------------------------------
;Jumping_CD
[State -1]
type = ChangeState
value = 640
triggerall = command = cd
trigger1 = statetype = A
trigger1 = ctrl = 1

;Jumping_CD
[State -1]
type = ChangeState
value = 640
triggerall = command = c
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_CD
[State -1]
type = ChangeState
value = 240
triggerall = command = cd
triggerall = command != holddown
trigger1 = statetype = S
trigger1 = ctrl = 1

;Stand_CD
[State -1]
type = ChangeState
value = 240
triggerall = command = c
triggerall = command != holddown
trigger1 = statetype = S
trigger1 = ctrl = 1

;Fwd a
[State -1]
type = ChangeState
value = 214
triggerall = command = holdfwd
triggerall = command = a
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = ctrl = 1
trigger2 = stateno = 210
trigger2 = movecontact = 1
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 611
trigger4 = movecontact = 1
trigger4 = pos y >= 0
trigger5 = stateno = 200
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 400
trigger7 = movecontact = 1
trigger8 = stateno = 211
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 201
trigger11 = movecontact = 1
;---------------------------------------------------------------------------
;back a
[State -1]
type = ChangeState
value = 214
triggerall = command = holdback
triggerall = command = a
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = ctrl = 1
trigger2 = stateno = 210
trigger2 = movecontact = 1
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 611
trigger4 = movecontact = 1
trigger4 = pos y >= 0
trigger5 = stateno = 200
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 400
trigger7 = movecontact = 1
trigger8 = stateno = 211
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 201
trigger11 = movecontact = 1
;---------------------------------------------------------------------------
;Fwd x
[State -1]
type = ChangeState
value = 204
triggerall = command = holdfwd
triggerall = command = x
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = ctrl = 1
trigger2 = stateno = 210
trigger2 = movecontact = 1
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 611
trigger4 = movecontact = 1
trigger4 = pos y >= 0
trigger5 = stateno = 200
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 400
trigger7 = movecontact = 1
trigger8 = stateno = 211
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 214
trigger11 = movecontact = 1
trigger12 = stateno = 201
trigger12 = movecontact = 1
;---------------------------------------------------------------------------
;back x
[State -1]
type = ChangeState
value = 204
triggerall = command = holdback
triggerall = command = x
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = ctrl = 1
trigger2 = stateno = 210
trigger2 = movecontact = 1
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 611
trigger4 = movecontact = 1
trigger4 = pos y >= 0
trigger5 = stateno = 200
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 400
trigger7 = movecontact = 1
trigger8 = stateno = 211
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 214
trigger11 = movecontact = 1
trigger12 = stateno = 201
trigger12 = movecontact = 1



;---------------------------------------------------------------------------
;DF+b
[State -1]
type = ChangeState
value = 215
triggerall = command = holdDF
triggerall = command = b
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger1 = ctrl = 1
trigger2 = stateno = 210
trigger2 = movecontact = 1
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 611
trigger4 = movecontact = 1
trigger4 = pos y >= 0
trigger5 = stateno = 200
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 400
trigger7 = movecontact = 1
trigger8 = stateno = 211
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 201
trigger11 = movecontact = 1
trigger12 = stateno = 204
trigger12 = movecontact = 1

;---------------------------------------------------------------------------
;DB+b
[State -1]
type = ChangeState
value = 215
triggerall = command = holdDB
triggerall = command = b
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger1 = ctrl = 1
trigger2 = stateno = 210
trigger2 = movecontact = 1
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 611
trigger4 = movecontact = 1
trigger4 = pos y >= 0
trigger5 = stateno = 200
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 400
trigger7 = movecontact = 1
trigger8 = stateno = 211
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 201
trigger11 = movecontact = 1
trigger12 = stateno = 204
trigger12 = movecontact = 1
;----------------------------------
;Stand_x
[State -1]
type = ChangeState
value = 200
triggerall = command = x
triggerall = command != holddown
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 210
trigger2 = movecontact = 1
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger3 = time >= 6
trigger4 = stateno = 611
trigger4 = movecontact = 1
trigger4 = pos y >= 0
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 400
trigger6 = movecontact = 1

;---------------------------------------------------------------------------
;Stand_y
[State -1]
type = ChangeState
value = 201
triggerall = command = y
triggerall = command != holddown
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 210
trigger2 = movecontact = 1
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 611
trigger4 = movecontact = 1
trigger4 = pos y >= 0

;---------------------------------------------------------------------------
;Stand_a
[State -1]
type = ChangeState
value = 210
triggerall = command = a
triggerall = command != holddown
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger3 = time >= 7
trigger4 = stateno = 611
trigger4 = movecontact = 1
trigger4 = pos y >= 0

;---------------------------------------------------------------------------
;Stand_B
[State -1]
type = ChangeState
value = 211
triggerall = command = b
triggerall = command != holddown
;triggerall = P2bodydist X > 32
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 611
trigger4 = movecontact = 1
trigger4 = pos y >= 0

;---------------------------------------------------------------------------
;Crouch_a
[State -1]
type = ChangeState
value = 410
triggerall = command = a
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 611
trigger4 = movecontact = 1
trigger4 = pos y >= 0
trigger5 = stateno = 410
trigger5 = movecontact = 1
;trigger5 = animelem >= 6
trigger6 = stateno = 400
trigger6 = movecontact = 1
;trigger6 = animelem >= 6

;---------------------------------------------------------------------------
;Crouch_x
[State -1]
type = ChangeState
value = 400
triggerall = command = x
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 611
trigger4 = movecontact = 1
trigger4 = pos y >= 0
trigger5 = stateno = 410
trigger5 = movecontact = 1
;trigger6 = stateno = 400


;---------------------------------------------------------------------------
;Crouch_B
[State -1]
type = ChangeState
value = 411
triggerall = command = b
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 400 ;crouch_a
trigger2 = movecontact = 1
trigger3 = stateno = 410 ;crouch_x
trigger3 = movecontact = 1
trigger4 = stateno = 200 ;stand_a
trigger4 = movecontact = 1
trigger5 = stateno = 210 ;stand_x
trigger5 = movecontact = 1

;---------------------------------------------------------------------------
;Crouch_y
[State -1]
type = ChangeState
value = 401
triggerall = command = y
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 400 ;crouch_a
trigger2 = movecontact = 1
trigger3 = stateno = 410 ;crouch_x
trigger3 = movecontact = 1
trigger4 = stateno = 200 ;stand_a
trigger4 = movecontact = 1
trigger5 = stateno = 210 ;stand_x
trigger5 = movecontact = 1
;---------------------------------------------------------------------------
;Jump_A
[State -1]
type = ChangeState
value = 610
trigger1 = command = a
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = a   ;-------
trigger2 = stateno = 600 ;jump_a
trigger2 = statetime >= 6

;---------------------------------------------------------------------------
;Jump_X
[State -1]
type = ChangeState
value = 600
trigger1 = command = x
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = a   ;-------
trigger2 = stateno = 600 ;jump_a
trigger2 = statetime >= 6

;---------------------------------------------------------------------------
;Jump_B forward
[State -1]
type = ChangeState
value = 611
;triggerall = vel X != 0
trigger1 = command = b
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = b   ;-------
trigger2 = stateno = 600 ;jump_a
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Jump_B Neutral
[State -1]
type = null;ChangeState
value = 613
triggerall = vel X = 0
trigger1 = command = b
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = b   ;-------
trigger2 = stateno = 600 ;jump_a
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Jump_y
[State -1]
type = ChangeState
value = 601
trigger1 = command = y
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = y   ;-------
trigger2 = stateno = 600 ;jump_a
trigger2 = movecontact = 1
